<!--
Copyright 2025 Genesis Corporation

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
-->

# API 参考

本节描述 RESTAlchemy 的公共 API 层。

主要模块：

- `restalchemy.api.applications`
- `restalchemy.api.routes`
- `restalchemy.api.controllers`
- `restalchemy.api.resources`
- `restalchemy.api.packers`
- `restalchemy.api.constants`
- `restalchemy.api.actions`
- `restalchemy.api.contexts`
- `restalchemy.api.field_permissions`
- `restalchemy.api.middlewares.*`

目前该参考以单页概览的形式提供。
